cgexplore.molecular.CgBead
==========================

.. currentmodule:: cgexplore.molecular

.. autoclass:: CgBead
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~CgBead.element_string
      ~CgBead.bead_type
      ~CgBead.bead_class
      ~CgBead.coordination
   
   